#!/usr/bin/env python2
#
#  Valosoitin - Audio player for EFL
#
#  Copyright 2012-2013 Kai Huuhko <kai.huuhko@gmail.com>
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 3 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
#  MA 02110-1301, USA.
#

import elementary as elm

class PlayControls(elm.Box):
    def __init__(self, parent):
        window = parent.window
        elm.Box.__init__(self, window)

        self.homogeneous = True

        prev = elm.Button(window)
        #prev.tooltip_text_set("Previous")
        prev_ic = elm.Icon(window)
        prev_ic.standard_set("media-skip-backward")
        prev.content_set(prev_ic)
        prev.callback_clicked_add(parent.nx, prev=True)
        prev.size_hint_min_set(30, 30)
        prev.size_hint_weight_set(1.0, 1.0)
        prev.size_hint_align_set(-1.0, -1.0)
        prev.show()

        self.play = play = elm.Button(window)
        #play.tooltip_text_set("Play")
        play_ic = elm.Icon(window)
        play_ic.standard_set("media-playback-start")
        play.content_set(play_ic)
        play.callback_clicked_add(parent.play_pause)
        play.size_hint_min_set(30, 30)
        play.size_hint_weight_set(1.0, 1.0)
        play.size_hint_align_set(-1.0, -1.0)
        play.show()

        nx = elm.Button(window)
        #nx.tooltip_text_set("Next")
        nx_ic = elm.Icon(window)
        nx_ic.standard_set("media-skip-forward")
        nx.content_set(nx_ic)
        nx.callback_clicked_add(parent.nx)
        nx.size_hint_min_set(30, 30)
        nx.size_hint_weight_set(1.0, 1.0)
        nx.size_hint_align_set(-1.0, -1.0)
        nx.show()

        self.horizontal_set(True)
        self.pack_end(prev)
        self.pack_end(play)
        self.pack_end(nx)
        self.size_hint_weight_set(1.0, 1.0)
        self.size_hint_align_set(-1.0, -1.0)
        self.show()

class VolumeControls(elm.Frame):
    def __init__(self, parent):
        window = parent.window
        elm.Frame.__init__(self, window)

        self.mute = mute = elm.Check(window)
        mute.text = _("Mute")
        try:
            mute.state = parent.conf.getboolean("Settings", "mute")
        except:
            pass
        mute.callback_changed_add(self.mute_cb, parent)
        mute.show()

        self.volume = volume = elm.Slider(window)
        volume.min_max = 0.0, 100.0
        volume.indicator_format_set("%.0f%")
        try:
            volume.value = parent.conf.getfloat("Settings", "volume")
        except:
            pass
        volume.disabled = mute.state
        volume.callback_changed_add(self.volume_cb, parent)
        volume.size_hint_weight = 1.0, 0.0
        volume.size_hint_align = -1.0, 0.0
        volume.show()

        self.size_hint_align = -1.0, 0.0
        volumebox = elm.Box(window)
        volumebox.horizontal = True
        volumebox.size_hint_weight = 1.0, 0.0
        volumebox.size_hint_align = -1.0, 0.0
        volumebox.pack_end(mute)
        volumebox.pack_end(volume)
        volumebox.show()
        self.content_set(volumebox)
        self.text = _("Volume control")
        self.show()

    def mute_cb(self, check, parent):
        parent.mute(check.state)

    def volume_cb(self, slider, parent):
        parent.change_volume(slider.value)

class PlayModes(elm.Frame):
    def __init__(self, parent):
        window = parent.window
        elm.Frame.__init__(self, window)

        self.single = single = elm.Check(window)
        single.text = _("Single")
        try:
            single.state = parent.conf.getboolean("Settings", "single")
        except:
            pass
        single.callback_changed_add(self.single_cb, parent)
        single.show()

        self.random = random = elm.Check(window)
        random.text = _("Random")
        try:
            random.state = parent.conf.getboolean("Settings", "random")
        except:
            pass
        random.callback_changed_add(self.random_cb, parent)
        random.show()

        self.repeat = repeat = elm.Check(window)
        repeat.text = _("Repeat")
        try:
            repeat.state = parent.conf.getboolean("Settings", "repeat")
        except:
            pass
        repeat.callback_changed_add(self.repeat_cb, parent)
        repeat.show()

        playmodes = elm.Box(window)
        playmodes.horizontal_set(True)
        playmodes.pack_end(single)
        playmodes.pack_end(random)
        playmodes.pack_end(repeat)
        playmodes.show()
        self.content_set(playmodes)
        self.text = _("Play modes")
        self.show()

    def single_cb(self, check, parent):
        parent.set_single_mode(check.state)

    def random_cb(self, check, parent):
        parent.set_random_mode(check.state)

    def repeat_cb(self, check, parent):
        parent.set_repeat_mode(check.state)

class SeekControls(elm.Box):
    def __init__(self, parent):
        window = parent.window
        elm.Box.__init__(self, window)

        self.seek = seek = elm.Slider(window)
        seek.callback_slider_drag_start_add(parent.seekstart)
        seek.callback_slider_drag_stop_add(parent.seektime)
        seek.size_hint_weight_set(1.0, 0.0)
        seek.size_hint_align_set(-1.0, 0.0)
        seek.show()

        self.seektime = seektime = elm.Label(window)
        seektime.text_set("0:00:00 / 0:00:00")
        seektime.show()

        self.horizontal_set(True)
        self.size_hint_weight_set(1.0, 0.0)
        self.size_hint_align_set(-1.0, 0.0)
        self.pack_end(seek)
        self.pack_end(seektime)
        self.show()
