#!/usr/bin/env python2
#
#  Valosoitin - Audio player for EFL
#
#  Copyright 2012-2013 Kai Huuhko <kai.huuhko@gmail.com>
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 3 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
#  MA 02110-1301, USA.
#

import os

import evas
import elementary as elm
import ecore

class ResultClass(elm.GenlistItemClass):
    def text_get(self, gl, part, m):
        artists = m.get("artist")
        artist = artists[0] if artists else ""
        albums = m.get("album")
        album = albums[0] if albums else ""
        titles = m.get("title")
        title = titles[0] if titles else os.path.basename(m.filename)
        return " - ".join(filter(None, (artist, album, title)))

class Results(elm.InnerWindow):
    def __init__(self, vs, string, result):
        self.vs = vs
        win = vs.window
        elm.InnerWindow.__init__(self, win)

        self.t = None

        box = elm.Box(win)
        self.content = box
        box.size_hint_weight = 1.0, 1.0
        box.size_hint_align = -1.0, -1.0

        search = self.search = elm.Entry(win)
        search.entry = string
        search.elm_event_callback_add(self.search_event_cb, vs)
        search.single_line = True
        search.focus = True
        search.show()
        f = elm.Frame(win)
        f.text = _("Search")
        f.size_hint_align_set(-1.0, 0.0)
        f.show()
        f.content = search

        gl = self.gl = elm.Genlist(win)
        gl.size_hint_weight = 1.0, 1.0
        gl.size_hint_align = -1.0, -1.0
        self.add_items(gl, result)
        gl.show()

        x = elm.Button(win)
        x.text = _("Close")
        x.callback_clicked_add(lambda x: self.delete())
        x.show()

        box.pack_end(f)
        box.pack_end(gl)
        box.pack_end(x)
        box.show()

        self.activate()
        search.cursor_end_set()

    def add_items(self, gl, result):
        for m in result:
            gl.item_append(ResultClass("no_icon"), m, func = self.result_select_cb)

    def search_event_cb(self, obj, entry, event_type, event, parent, *args):
        if event_type == evas.EVAS_CALLBACK_KEY_UP:
            if event.keyname == "Return":
                if entry.entry:
                    s = entry.entry
                    if self.t:
                        self.t.cancel()
                    if len(s) > 2:
                        parent.search(s, self.search_cb)
            elif event.keyname == "Escape":
                self.delete()
            else:
                if self.t:
                    self.t.delete()
                self.t = ecore.Timer(2.0, self.search_items, entry, parent)
                #self.t.start()

        return True

    def search_items(self, *args):
        entry, parent = args
        if entry.entry:
            s = entry.entry
            if len(s) > 2:
                parent.search(s, self.search_cb)

        return False

    def search_cb(self, string, result):
        self.gl.clear()
        self.add_items(self.gl, result)

    def result_select_cb(self, gl, glitem, m):
        self.vs.play_file(m.filename)
